@@ -1,36 +1,37 @@
 /*  This file is part of YUView - The YUV player with advanced analytics toolset
-*   <https://github.com/IENT/YUView>
-*   Copyright (C) 2015  Institut für Nachrichtentechnik, RWTH Aachen University, GERMANY
-*
-*   This program is free software; you can redistribute it and/or modify
-*   it under the terms of the GNU General Public License as published by
-*   the Free Software Foundation; either version 3 of the License, or
-*   (at your option) any later version.
-*
-*   In addition, as a special exception, the copyright holders give
-*   permission to link the code of portions of this program with the
-*   OpenSSL library under certain conditions as described in each
-*   individual source file, and distribute linked combinations including
-*   the two.
-*   
-*   You must obey the GNU General Public License in all respects for all
-*   of the code used other than OpenSSL. If you modify file(s) with this
-*   exception, you may extend this exception to your version of the
-*   file(s), but you are not obligated to do so. If you do not wish to do
-*   so, delete this exception statement from your version. If you delete
-*   this exception statement from all source files in the program, then
-*   also delete it here.
-*
-*   This program is distributed in the hope that it will be useful,
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-*   GNU General Public License for more details.
-*
-*   You should have received a copy of the GNU General Public License
-*   along with this program. If not, see <http://www.gnu.org/licenses/>.
-*/
+ *   <https://github.com/IENT/YUView>
+ *   Copyright (C) 2015  Institut für Nachrichtentechnik, RWTH Aachen University, GERMANY
+ *
+ *   This program is free software; you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation; either version 3 of the License, or
+ *   (at your option) any later version.
+ *
+ *   In addition, as a special exception, the copyright holders give
+ *   permission to link the code of portions of this program with the
+ *   OpenSSL library under certain conditions as described in each
+ *   individual source file, and distribute linked combinations including
+ *   the two.
+ *
+ *   You must obey the GNU General Public License in all respects for all
+ *   of the code used other than OpenSSL. If you modify file(s) with this
+ *   exception, you may extend this exception to your version of the
+ *   file(s), but you are not obligated to do so. If you do not wish to do
+ *   so, delete this exception statement from your version. If you delete
+ *   this exception statement from all source files in the program, then
+ *   also delete it here.
+ *
+ *   This program is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ *   GNU General Public License for more details.
+ *
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "playlistItem.h"
+
 #include <QPainter>
 
 unsigned int playlistItem::idCounter = 0;
@@ -39,46 +40,42 @@ playlistItem::playlistItem(const QString &itemNameOrFileName, Type type)
 {
   this->setName(itemNameOrFileName);
   this->setType(type);
-  
-  // Whenever a playlistItem is created, we give it an ID (which is unique for this instance of YUView)
+
+  // Whenever a playlistItem is created, we give it an ID (which is unique for this instance of
+  // YUView)
   this->prop.id = idCounter++;
 }
 
-playlistItem::~playlistItem()
-{
-}
+playlistItem::~playlistItem() {}
 
 void playlistItem::setName(const QString &name)
-{ 
+{
   this->prop.name = name;
   // For the text that is shown in the playlist, remove all newline characters.
-  setText(0, name.simplified());
+  this->setText(0, name.simplified());
 }
 
-void playlistItem::drawItem(QPainter *painter, int frameIdx, double zoomFactor, bool drawRawValues)
+void playlistItem::drawItem(QPainter *painter, int, double zoomFactor, bool)
 {
-  Q_UNUSED(frameIdx);
-  Q_UNUSED(drawRawValues);
-
   // Draw an error text in the view instead of showing an empty image
   // Get the size of the text and create a QRect of that size which is centered at (0,0)
-  QFont displayFont = painter->font();
+  auto displayFont = painter->font();
   displayFont.setPointSizeF(painter->font().pointSizeF() * zoomFactor);
   painter->setFont(displayFont);
-  QSize textSize = painter->fontMetrics().size(0, infoText);
+  auto textSize = painter->fontMetrics().size(0, infoText);
   QRect textRect;
   textRect.setSize(textSize);
-  textRect.moveCenter(QPoint(0,0));
+  textRect.moveCenter(QPoint(0, 0));
 
   // Draw the text
   painter->drawText(textRect, infoText);
 }
 
 QSize playlistItem::getSize() const
-{ 
+{
   // Return the size of the text that is drawn on screen.
   QPainter painter;
-  QFont displayFont = painter.font();
+  auto    displayFont = painter.font();
   return painter.fontMetrics().size(0, infoText);
 }
 
@@ -91,7 +88,7 @@ void playlistItem::setType(Type newType)
     ui.labelRate->setVisible(showIndexed);
     ui.rateSpinBox->setVisible(showIndexed);
 
-    auto showStatic  = (newType == Type::Static);
+    auto showStatic = (newType == Type::Static);
     ui.durationLabel->setVisible(showStatic);
     ui.durationSpinBox->setVisible(showStatic);
   }
@@ -139,15 +136,13 @@ void playlistItem::loadPropertiesFromPlaylist(const YUViewDomElement &root, play
 void playlistItem::slotVideoControlChanged()
 {
   if (this->properties().type == Type::Static)
-  {
     this->prop.duration = ui.durationSpinBox->value();
-  }
   else
   {
     this->prop.frameRate = ui.rateSpinBox->value();
     // The current frame in the buffer is not invalid, but emit that something has changed.
     // Also no frame in the cache is invalid.
-    emit signalItemChanged(false, RECACHE_NONE);
+    emit SignalItemChanged(false, RECACHE_NONE);
   }
 }
 
@@ -168,8 +163,14 @@ QLayout *playlistItem::createPlaylistItemControls()
   this->setType(this->properties().type);
 
   // Connect all the change signals from the controls to "connectWidgetSignals()"
-  connect(ui.rateSpinBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &playlistItem::slotVideoControlChanged);
-  connect(ui.durationSpinBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &playlistItem::slotVideoControlChanged);
+  connect(ui.rateSpinBox,
+          QOverload<double>::of(&QDoubleSpinBox::valueChanged),
+          this,
+          &playlistItem::slotVideoControlChanged);
+  connect(ui.durationSpinBox,
+          QOverload<double>::of(&QDoubleSpinBox::valueChanged),
+          this,
+          &playlistItem::slotVideoControlChanged);
 
   return ui.gridLayout;
 }
@@ -178,23 +179,21 @@ void playlistItem::createPropertiesWidget()
 {
   Q_ASSERT_X(!this->propertiesWidget, "createPropertiesWidget", "Properties widget already exists");
 
-  preparePropertiesWidget(QStringLiteral("playlistItem"));
+  this->preparePropertiesWidget(QStringLiteral("playlistItem"));
 
   // On the top level everything is layout vertically
-  QVBoxLayout *vAllLaout = new QVBoxLayout(propertiesWidget.data());
+  auto vAllLaout = new QVBoxLayout(this->propertiesWidget.data());
 
   // First add the parents controls (duration) then the text specific controls (font, text...)
   vAllLaout->addLayout(createPlaylistItemControls());
 
-  // Insert a stretch at the bottom of the vertical global layout so that everything
-  // gets 'pushed' to the top
-  vAllLaout->insertStretch(2, 1);
+  vAllLaout->insertStretch(-1, 1); // Push controls up
 }
 
 void playlistItem::preparePropertiesWidget(const QString &name)
 {
-  assert(!propertiesWidget);
+  assert(!this->propertiesWidget);
 
-  propertiesWidget.reset(new QWidget);
-  propertiesWidget->setObjectName(name);
+  this->propertiesWidget.reset(new QWidget);
+  this->propertiesWidget->setObjectName(name);
 }
